==> ejc-proequipmentcorp-impl-3.0.0-20221027.061535-68-sources.jar: com/ejianc/business/proequipmentcorpout/contract/service/IOutRentContractService.java <==
package com.ejianc.business.proequipmentcorpout.contract.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractEntity;
import com.ejianc.business.proequipmentcorpout.contract.vo.OutRentContractEquipmentAllVO;
import com.ejianc.business.proequipmentcorpout.contract.vo.OutRentContractVO;
import com.ejianc.business.profinance.vo.ContractPaymentResultVO;
import com.ejianc.business.targetcost.vo.ExecutionVO;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.business.tender.common.vo.SignContractVo;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.util.List;
import java.util.Map;

/**
 * 租赁合同
 * 
 * @author generator
 * 
 */
public interface IOutRentContractService extends IBaseService<OutRentContractEntity> {
    /**
     * 补充协议
     * @param OutRentContractVO
     */
    public OutRentContractVO saveOrUpdateSupplement(OutRentContractVO OutRentContractVO, String authority);

    boolean checkContract(Long id, Long otherId);

    public OutRentContractVO addConvertByConId(Long contractId);

    public Boolean addSupplementFlag(Long id);
    ExecutionVO targetCost(OutRentContractVO contractVO, String linkUrl);


    public Map<String, Object> countContractAmount(QueryParam param);

    public OutRentContractVO querySupplementRecord(Long id);
    void pushContract(OutRentContractVO contractVO);
    String validateContract(Long contractId, String billType, Long billId, String type);


    /**
     * 子表合计
     * @param param
     * @return
     */
    public IPage<OutRentContractEquipmentAllVO> queryEquipmentSubList(Map<String, Object> param);

    public Boolean delContractFile(Long contractFileId, String authority);

    public CommonResponse<String> deleteByIds(List<OutRentContractVO> vos);

    /**
     *
     * 查询合同编码是否重复
     * @param code
     * @return
     */
    public OutRentContractEntity selectCode(String code);

    /**
     * 弃审后删除合同池中的合同
     *
     * @param contractVO 需要删除的合同数据
     */
    void pushDelContract(OutRentContractVO contractVO);


    CommonResponse<OutRentContractVO> saveOrUpdate(OutRentContractVO saveOrUpdateVO, String authority, Boolean isControl);

    ParamsCheckVO targetCostCtrl(OutRentContractVO contractVO, String authority);

    ParamsCheckVO viewTargetCostCtrlInfo(Long id);

    OutRentContractVO queryDetail(Long id);

    CommonResponse<String> pushTargetCost(Long id);
    /**
     * 单据管控-合同金额大于总计划金额
     * @return
     */
    List<ParamsCheckVO> checkParamsMnyPlan(OutRentContractVO vo);
    /**
     * 单据管控-补充协议金额大于合同金额
     * @return
     */
    List<ParamsCheckVO> checkParamsMnySup(OutRentContractVO vo);

    ParamsCheckVO checkParams(OutRentContractVO vo, ParamsCheckVO paramsCheckVO2);

    /**
     * 删除文件中心水印文件
     *
     * @param watermarkFileId 水印合同附件id
     * @return boolean 是否删除标识
     */
    boolean delWatermarkContractFile(Long watermarkFileId);

    ContractPaymentResultVO queryPaymentApplyList(Long id);

    /*施工合同 控 补充协议,主合同
     *        @param 最新合同vo  或 协议vo

     * */
    List<ParamsCheckVO>  checkParamsConstruction(OutRentContractVO vo);

    void updateTargetResult(OutRentContractEntity vo, Integer type);

    Boolean validateTargetMny(OutRentContractEntity entity);

    List<SignContractVo> queryContractByTargetResultId(List<String> targetResultIdList);

    /**
     * 根据合同id给水印文件赋值
     *
     * @param id 合同id
     */
    void asyncWatermarkById(Long id);

    /**
     * 获取合同归档控制参数  没有获取到参数默认不限制
     *
     * @return 合同归档控制参数(0：不限制，1：部分限制，2：全部限制)
     */
    String getContractFilingCode();

    /**
     * 根据合同归档控制参数，校验合同能否新增变更、补充协议
     *
     * @param contractId 合同id
     * @return true：可以新增，false：不能新增
     */
    boolean checkContractFiling(Long contractId);
}

==> ejc-proequipmentcorp-impl-3.0.0-20230525.035006-412-sources.jar: com/ejianc/business/proequipmentcorpout/contract/service/IOutRentContractService.java <==
package com.ejianc.business.proequipmentcorpout.contract.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractEntity;
import com.ejianc.business.proequipmentcorpout.contract.vo.OutRentContractEquipmentAllVO;
import com.ejianc.business.proequipmentcorpout.contract.vo.OutRentContractVO;
import com.ejianc.business.profinance.vo.ContractPaymentResultVO;
import com.ejianc.business.targetcost.vo.ExecutionVO;
import com.ejianc.business.targetcost.vo.ParamsCheckVO;
import com.ejianc.business.tender.common.vo.SignContractVo;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.util.List;
import java.util.Map;

/**
 * 租赁合同
 *
 * @author generator
 *
 */
public interface IOutRentContractService extends IBaseService<OutRentContractEntity> {
    /**
     * 补充协议
     * @param OutRentContractVO
     */
    public OutRentContractVO saveOrUpdateSupplement(OutRentContractVO OutRentContractVO, String authority);

    boolean checkContract(Long id, Long otherId);

    public OutRentContractVO addConvertByConId(Long contractId);

    public Boolean addSupplementFlag(Long id);

    ExecutionVO targetCost(OutRentContractVO contractVO, String linkUrl);


    public Map<String, Object> countContractAmount(QueryParam param);

    public OutRentContractVO querySupplementRecord(Long id);

    void pushContract(OutRentContractVO contractVO);

    String validateContract(Long contractId, String billType, Long billId, String type);


    /**
     * 子表合计
     * @param param
     * @return
     */
    public IPage<OutRentContractEquipmentAllVO> queryEquipmentSubList(Map<String, Object> param);

    public Boolean delContractFile(Long contractFileId, String authority);

    public CommonResponse<String> deleteByIds(List<OutRentContractVO> vos);

    /**
     *
     * 查询合同编码是否重复
     * @param code
     * @return
     */
    public OutRentContractEntity selectCode(String code);

    /**
     * 弃审后删除合同池中的合同
     *
     * @param contractVO 需要删除的合同数据
     */
    void pushDelContract(OutRentContractVO contractVO);


    CommonResponse<OutRentContractVO> saveOrUpdate(OutRentContractVO saveOrUpdateVO, String authority, Boolean isControl);

    ParamsCheckVO targetCostCtrl(OutRentContractVO contractVO, String authority);

    ParamsCheckVO viewTargetCostCtrlInfo(Long id);

    OutRentContractVO queryDetail(Long id);

    CommonResponse<String> pushTargetCost(Long id);

    /**
     * 单据管控-合同金额大于总计划金额
     * @return
     */
    List<ParamsCheckVO> checkParamsMnyPlan(OutRentContractVO vo);

    /**
     * 单据管控-补充协议金额大于合同金额
     * @return
     */
    List<ParamsCheckVO> checkParamsMnySup(OutRentContractVO vo);

    ParamsCheckVO checkParams(OutRentContractVO vo, ParamsCheckVO paramsCheckVO2);

    /**
     * 删除文件中心水印文件
     *
     * @param watermarkFileId 水印合同附件id
     * @return boolean 是否删除标识
     */
    boolean delWatermarkContractFile(Long watermarkFileId);

    ContractPaymentResultVO queryPaymentApplyList(Long id);

    /*施工合同 控 补充协议,主合同
     *        @param 最新合同vo  或 协议vo

     * */
    List<ParamsCheckVO>  checkParamsConstruction(OutRentContractVO vo);

    void updateTargetResult(OutRentContractEntity vo, Integer type);

    Boolean validateTargetMny(OutRentContractEntity entity);

    List<SignContractVo> queryContractByTargetResultId(List<String> targetResultIdList);

    /**
     * 获取合同归档控制参数  没有获取到参数默认不限制
     *
     * @return 合同归档控制参数(0：不限制，1：部分限制，2：全部限制)
     */
    String getContractFilingCode();

    /**
     * 根据合同归档控制参数，校验合同能否新增变更、补充协议
     *
     * @param contractId 合同id
     * @return true：可以新增，false：不能新增
     */
    boolean checkContractFiling(Long contractId);

    /**
     * 修改合同授权委托书签订状态
     *
     * @param proxyId   合同授权委托书id
     * @param signState 签订状态1-未签订，2-已签订
     */
    void updateProxyContract(Long proxyId, Integer signState);

    /**
     * 推送合同到设备租赁
     *
     * @param jsonVo  合同信息
     * @param optType 操作类型
     * @param optBill 操作单据
     */
    void pushContractToRent(String jsonVo, Integer optType, String optBill);
}
